@@ -14,7 +14,6 @@ import socket
 import sys
 
 from portage import os
-from portage import _encodings
 from portage import _unicode_decode, _unicode_encode
 from portage.localization import _
 import portage
@@ -137,4 +136,3 @@ def send_mail(mysettings, message):
 			raise portage.exception.PortageException(_("!!! An error occurred while trying to send logmail:\n")+str(e))
 		except socket.error as e:
 			raise portage.exception.PortageException(_("!!! A network error occurred while trying to send logmail:\n%s\nSure you configured PORTAGE_ELOG_MAILURI correctly?") % str(e))
-	return
